# -*- coding: utf-8 -*-

"""
@date: 2020/7/13 下午4:03
@file: __init__.py.py
@author: zj
@description: 
"""

# This line will be programatically read/write by setup.py.
# Leave them at the bottom of this file and don't touch them.
__version__ = "0.3.4"
